Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputeHash ¶
ComputeHash computes the SHA256 hash of the user source code and the visible symbols/types.
Types ¶
type Cache ¶
type Cache struct {
// contains filtered or unexported fields
}
Cache manages the registry of compiled plugins identified by a SHA256 hash.
type Loader ¶
type Loader struct{}
Loader dynamically loads a .so file and extracts the Execute symbol.
type PanicError ¶
PanicError describes a panic recovered from a cell's Execute. GeneratedLine, when non-zero, is the line in the compiled plugin's own generated main.go where the panic actually occurred (the innermost stack frame whose file is that plugin's main.go) -- session-level code, which is the only place that knows how GeneratePluginCode mapped this specific cell's lines to that file, is responsible for translating it back to the cell's own line number.
func (*PanicError) Error ¶
func (e *PanicError) Error() string